# deriva-qt
[![PyPi Version](https://img.shields.io/pypi/v/deriva-qt.svg)](https://pypi.python.org/pypi/deriva-qt)
[![PyPi Wheel](https://img.shields.io/pypi/wheel/deriva-qt.svg)](https://pypi.python.org/pypi/deriva-qt)
[![Python Versions](https://img.shields.io/pypi/pyversions/deriva-qt.svg)](https://pypi.python.org/pypi/deriva-qt)
[![License](https://img.shields.io/pypi/l/deriva-qt.svg)](https://www.gnu.org/licenses/gpl-3.0)

Graphical User Interface tools for DERIVA using PyQt5

* Authentication Agent
* File Uploader

## Installation
### Windows / MacOS
Windows and MacOS users can download prebuilt bundles which include all
dependencies [here](https://github.com/informatics-isi-edu/deriva-client-bundle/releases).
Download the appropriate file for your OS.

## Install from source

See the source installation instructions [here](https://github.com/informatics-isi-edu/deriva-client-bundle/blob/master/README.md).


## User Instructions 

TBD


## Additional information
Links:
* [Build status](http://buildbot.isrd.isi.edu/)
* [Downloads](http://buildbot.isrd.isi.edu/~buildbot/deriva-client-bundle/)
